@@ -82,6 +82,8 @@ from selenium.webdriver.support import expected_conditions as EC  # 等待页面
 
 from pyefun import *
 import requests
+from pyefun.模块.通用实用函数 import *
+from pyefun.编码解码.zip解压缩 import *
 
 键盘_F1 = '\ue031'
 键盘_F2 = '\ue032'
@@ -273,6 +275,19 @@ class 浏览器类():
 
         return True
 
+    def 隐藏特征(self):
+        folder = os.path.dirname(os.path.abspath(__file__))
+        stealth = os.path.join(folder, "stealth.min.js")
+        js = 读入文本(stealth)
+        self.浏览器.execute_cdp_cmd("Page.addScriptToEvaluateOnNewDocument", {
+            "source": js
+        })
+
+    def 下载隐藏特征文件(self):
+        folder = os.path.dirname(os.path.abspath(__file__))
+        stealth = os.path.join(folder, "stealth.min.js")
+        下载文件("https://raw.githubusercontent.com/requireCool/stealth.min.js/main/stealth.min.js", stealth)
+
     def 浏览网页(self, URL地址, 隐藏Navigator=True):
         """
         浏览指定网页。本命令为初级对象成员命令。
